@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-03-15'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -11,6 +11,7 @@ with 'Pod::Weaver::Role::Section';
 has include_module => (is=>'rw');
 has exclude_module => (is=>'rw');
 has bench => (is=>'rw', default=>sub{1});
+has bench_startup => (is=>'rw', default=>sub{1});
 has sample_bench => (is=>'rw');
 
 sub mvp_multivalue_args { qw(sample_bench include_module exclude_module) }
@@ -174,7 +175,7 @@ sub _process_module {
             push @bench_res, $bench_res;
         } # for sample_benches
 
-        if (@modules && !$scenario->{module_startup}) {
+        if ($self->bench_startup && @modules && !$scenario->{module_startup}) {
             $self->log(["Running module_startup benchmark"]);
             my $bench_res2 = Bencher::Backend::bencher(
                 action => 'bench',
@@ -341,7 +342,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.14 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-03-15.
+This document describes version 0.15 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -392,7 +393,12 @@ be specified multiple times.
 
 =head2 bench => bool (default: 1)
 
-Set to 0 if you do not want to produce sample results
+Set to 0 if you do not want to produce any sample benchmarks (including module
+startup benchmark).
+
+=head2 bench_startup => bool (default: 1)
+
+Set to 0 if you do not want to produce module startup sample benchmark.
 
 =head1 HOMEPAGE
 
